@@ -55,6 +55,9 @@ def handle_db_dict(db_dict: dict) -> dict:
     try:
         db_dict['id'] = str(db_dict['_id'])
         del db_dict['_id']
+        # 创建时间和更新时间如果不存在，则设置为当前时间
+        db_dict['creation_time'] = db_dict.get('creation_time', datetime.today())
+        db_dict['update_time'] = db_dict.get('update_time', datetime.today())
         # 将日期格式的时间，转化为13位时间戳
         db_dict['creation_time'] = int(time.mktime(
             db_dict['creation_time'].timetuple())) * 1000
